@@ -13,7 +13,18 @@ protected:
     FXDataTarget*      string_target;
     FXHorizontalFrame* checkbutton;
 	FXPopup*		   popup;
-	FXuint			   archformat;
+	FXOptionMenu*		optionmenu;
+	FXOption* 			option_tgz;	
+	FXOption* 			option_zip;	
+	FXOption* 			option_tbz2;	
+	FXOption* 			option_tar;	
+	FXOption* 			option_taz; 	
+	FXOption* 			option_gz ;	
+	FXOption* 			option_bz2;	
+	FXOption* 			option_z;	
+	FXOption* 			option_rar;	
+	FXOption* 			option_lzh; 	
+
 private:
     ArchInputDialog()
     {
@@ -40,6 +51,7 @@ public:
     long onCmdKeyPress(FXObject*,FXSelector,void*);
 	long onCmdBrowsePath(FXObject*,FXSelector,void*);
 	long onCmdOption(FXObject*,FXSelector,void*);
+	long onUpdOption(FXObject*,FXSelector,void*);
     FXString getText()
     {
         return input->getText();
