@@ -95,6 +95,8 @@ FXDEFMAP(DirList) DirListMap[]=
 	FXMAPFUNC(SEL_COMMAND,DirList::ID_SET_PATTERN,DirList::onCmdSetPattern),
 	FXMAPFUNC(SEL_COMMAND,DirList::ID_SORT_REVERSE,DirList::onCmdSortReverse),
 	FXMAPFUNC(SEL_COMMAND,DirList::ID_REFRESH,DirList::onCmdRefresh),
+	FXMAPFUNC(SEL_COMMAND,DirList::ID_SORT_CASE,DirList::onCmdSortCase),
+	FXMAPFUNC(SEL_UPDATE,DirList::ID_SORT_CASE,DirList::onUpdSortCase)
 };
 
 
@@ -255,7 +257,7 @@ TreeItem* DirList::createItem(const FXString& text,FXIcon* oi,FXIcon* ci,void* p
 
 
 // Sort ascending order, keeping directories first
-FXint DirList::ascending(const TreeItem* pa,const TreeItem* pb)
+FXint DirList::ascending(const FXTreeItem* pa,const FXTreeItem* pb)
 {
     register const DirItem *a=(DirItem*)pa;
     register const DirItem *b=(DirItem*)pb;
@@ -265,7 +267,7 @@ FXint DirList::ascending(const TreeItem* pa,const TreeItem* pb)
 
 
 // Sort descending order, keeping directories first
-FXint DirList::descending(const TreeItem* pa,const TreeItem* pb)
+FXint DirList::descending(const FXTreeItem* pa,const FXTreeItem* pb)
 {
     register const DirItem *a=(DirItem*)pa;
     register const DirItem *b=(DirItem*)pb;
@@ -275,7 +277,7 @@ FXint DirList::descending(const TreeItem* pa,const TreeItem* pb)
 
 
 // Sort ascending order, case insensitive, keeping directories first
-FXint DirList::ascendingCase(const TreeItem* pa,const TreeItem* pb)
+FXint DirList::ascendingCase(const FXTreeItem* pa,const FXTreeItem* pb)
 {
     register const DirItem *a=(DirItem*)pa;
     register const DirItem *b=(DirItem*)pb;
@@ -285,7 +287,7 @@ FXint DirList::ascendingCase(const TreeItem* pa,const TreeItem* pb)
 
 
 // Sort descending order, case insensitive, keeping directories first
-FXint DirList::descendingCase(const TreeItem* pa,const TreeItem* pb)
+FXint DirList::descendingCase(const FXTreeItem* pa,const FXTreeItem* pb)
 {
     register const DirItem *a=(DirItem*)pa;
     register const DirItem *b=(DirItem*)pb;
@@ -622,7 +624,7 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
         }
         delete f;
         FXFREE(&data);
-         
+        
 		// Refresh the DirList and the FilePanel
 		//setDirectory(targetdir,TRUE);
 		//((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(targetdir);
