@@ -162,10 +162,10 @@ public:
 	long onCmdDragLink(FXObject* sender,FXSelector,void*);
 	long onCmdDragReject(FXObject* sender,FXSelector,void*);
 public:
-    static FXint ascending(const TreeItem* a,const TreeItem* b);
-    static FXint descending(const TreeItem* a,const TreeItem* b);
-    static FXint ascendingCase(const TreeItem* a,const TreeItem* b);
-    static FXint descendingCase(const TreeItem* a,const TreeItem* b);
+    static FXint ascending(const FXTreeItem* a,const FXTreeItem* b);
+    static FXint descending(const FXTreeItem* a,const FXTreeItem* b);
+    static FXint ascendingCase(const FXTreeItem* a,const FXTreeItem* b);
+    static FXint descendingCase(const FXTreeItem* a,const FXTreeItem* b);
 public:
     enum {
         ID_REFRESH_TIMER=FXTreeList::ID_LAST,
@@ -177,6 +177,7 @@ public:
         ID_TOGGLE_HIDDEN,
         ID_SET_PATTERN,
         ID_SORT_REVERSE,
+        ID_SORT_CASE,
         ID_EXPAND_TIMER,
 #if defined(linux)
         ID_UPDEVICES_REFRESH,
@@ -230,10 +231,10 @@ public:
     // Return name of item
     FXString getItemFilename(const TreeItem* item) const;
 
-    /// Return absolute pathname of item
+    // Return absolute pathname of item
     FXString getItemPathname(const TreeItem* item) const;
 
-    /// Return the item from the absolute pathname
+    // Return the item from the absolute pathname
     TreeItem* getPathnameItem(const FXString& path);
 
     // Change wildcard matching pattern
