@@ -199,7 +199,7 @@ hop:
             }
         }
 
-        //!!!! Hack to change the KEY_up and KEY_down behaviour !!!
+        // !!!! Hack to change the KEY_up and KEY_down behaviour !!!
 		fromKeyPress=TRUE;
 		// !!!! End of hack !!!
 		handle(this,FXSEL(SEL_CLICKED,0),(void*)currentitem);
@@ -295,7 +295,6 @@ FXDEFMAP(DirPanel) DirPanelMap[]={
 	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_ARCHIVE,DirPanel::onCmdAddToArch),
 	FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,DirPanel::ID_FILELIST,DirPanel::onCmdPopupMenu),
 	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_POPUP_MENU,DirPanel::onCmdPopupMenu),
-	FXMAPFUNC(SEL_COMMAND,DirPanel::ID_CTRL_POPUP_MENU,DirPanel::onCmdCtrlPopupMenu),
 	FXMAPFUNC(SEL_CLICKED,DirPanel::ID_FILELIST,DirPanel::onCmdDirectory),
 	FXMAPFUNC(SEL_UPDATE,DirPanel::ID_FILELIST,DirPanel::onUpdDirectory),
 	FXMAPFUNC(SEL_EXPANDED,DirPanel::ID_FILELIST,DirPanel::onExpand),
@@ -443,16 +442,16 @@ long DirPanel::onCmdDirectory(FXObject*,FXSelector,void* ptr)
             MessageBox::error(this,BOX_OK_SU,_("Error"),_(" Permission to: %s denied."), directory.text());
             return 0;
         }
-		FilePanel* currentpanel=((XFileExplorer*) mainWindow)->lpanel->current;
-		FXComboBox* address=((XFileExplorer*) mainWindow)->address;
-        currentpanel->list->setDirectory(directory);
+		FilePanel* currentpanel=((XFileExplorer*) mainWindow)->getCurrentPanel();
+		FXComboBox* address=((XFileExplorer*) mainWindow)->getAddressBox();
+        currentpanel->setDirectory(directory);
         currentpanel->updatePathLinker();
         
 		// Remember latest directory in the location address
        	FXString item;
 		FXint i=0;
 		FXint count=address->getNumItems();
-       	FXString p=currentpanel->list->getDirectory();
+       	FXString p=currentpanel->getDirectory();
 
 		if(!count)
 		{
@@ -469,7 +468,7 @@ long DirPanel::onCmdDirectory(FXObject*,FXSelector,void* ptr)
 			}
        	}
        	if(i==count)
-			address->insertItem(0,currentpanel->list->getDirectory());
+			address->insertItem(0,currentpanel->getDirectory());
 
     }
 
@@ -494,7 +493,7 @@ long DirPanel::onUpdDirectory(FXObject*,FXSelector,void* ptr)
 	FXString dirpath=list->getDirectory();
 	
 	// FileList directory
-	FXString filepath=((XFileExplorer*) mainWindow)->lpanel->current->list->getDirectory();
+	FXString filepath=((XFileExplorer*) mainWindow)->getCurrentPanel()->getDirectory();
 		
 	// Update if they are different
 	if (dirpath!=filepath)
@@ -538,16 +537,6 @@ long DirPanel::onUpdToggleTree(FXObject* sender,FXSelector sel,void* ptr)
 }
 
 
-long DirPanel::onCmdCtrlPopupMenu(FXObject* o,FXSelector s,void*)
-{
-	// To select the control popup menu
-	ctrlflag=TRUE;
-    handle(this,FXSEL(SEL_COMMAND,ID_POPUP_MENU),NULL);
-	return 1;
-	
-}
-
-
 // Directory list context menu
 long DirPanel::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
 {
@@ -566,16 +555,18 @@ long DirPanel::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
 	list->getCursorPosition(xitem,yitem,state);   	    
 	DirItem* item=(DirItem*)list->getItemAt(xitem,yitem);
 
-	// If no item under cursor, then return
-	if (item==NULL)
-		return 0;
-
 	// If item, then set it current and set directory in DirList and FileList
-	list->setCurrentItem(item,TRUE);
-	FXString dir=list->getItemPathname((TreeItem*)item);
-	list->setDirectory(dir,TRUE);
-	((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(dir);
-	((XFileExplorer*) mainWindow)->lpanel->current->updatePathLinker();
+	FXString dir;
+	if (item)
+	{
+		list->setCurrentItem(item,TRUE);
+		dir=list->getItemPathname((TreeItem*)item);
+		list->setDirectory(dir,TRUE);
+		((XFileExplorer*) mainWindow)->getCurrentPanel()->setDirectory(dir);
+		((XFileExplorer*) mainWindow)->getCurrentPanel()->updatePathLinker();
+	}
+	else
+		ctrlflag=TRUE;
 	
     // Popup menu pane
     FXMenuPane *menu = new FXMenuPane(this);
@@ -593,6 +584,7 @@ long DirPanel::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
 
 		new FXMenuSeparator(menu);
 		new FXMenuCheck(menu,_("&Hidden folders"),this,DirPanel::ID_TOGGLE_HIDDEN);
+  		new FXMenuCheck(menu,_("Ignore c&ase"),list,DirList::ID_SORT_CASE);
 		new FXMenuCheck(menu,_("&Reverse order"),list,DirList::ID_SORT_REVERSE);
 		new FXMenuCommand(menu,_("E&xpand tree"),exptreeicon,this,DirPanel::ID_EXPANDTREE);
 		new FXMenuCommand(menu,_("Collap&se tree"),colltreeicon,this,DirPanel::ID_COLLAPSETREE);
@@ -606,6 +598,7 @@ long DirPanel::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
 
 		new FXMenuSeparator(submenu);
 		new FXMenuCheck(submenu,_("&Hidden folders"),this,DirPanel::ID_TOGGLE_HIDDEN);
+  		new FXMenuCheck(submenu,_("Ignore c&ase"),list,DirList::ID_SORT_CASE);
 		new FXMenuCheck(submenu,_("&Reverse order"),list,DirList::ID_SORT_REVERSE);
 		new FXMenuCommand(submenu,_("E&xpand tree"),exptreeicon,this,DirPanel::ID_EXPANDTREE);
 		new FXMenuCommand(submenu,_("Collap&se tree"),colltreeicon,this,DirPanel::ID_COLLAPSETREE);
@@ -829,8 +822,8 @@ long DirPanel::onCmdAddToArch(FXObject* o,FXSelector,void*)
 
 		// Display parent directory in DirList and FileList
 		list->setDirectory(parentdir,TRUE);
-		((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(parentdir);
-		((XFileExplorer*) mainWindow)->lpanel->current->updatePathLinker();
+		((XFileExplorer*) mainWindow)->getCurrentPanel()->setDirectory(parentdir);
+		((XFileExplorer*) mainWindow)->getCurrentPanel()->updatePathLinker();
     }
     return 1;
 }
@@ -1014,7 +1007,7 @@ long DirPanel::onCmdPaste(FXObject*,FXSelector sel,void*)
 	FXbool from_kde=FALSE;
 	
     // Target directory
-	FXString targetdir=((XFileExplorer*) mainWindow)->lpanel->current->list->getDirectory();
+	FXString targetdir=((XFileExplorer*) mainWindow)->getCurrentPanel()->getDirectory();
 	
 	// If source is xfelistType (Gnome, XFCE, or Xfe app)
     if(getDNDData(FROM_CLIPBOARD,xfelistType,data,len))
@@ -1555,8 +1548,8 @@ long DirPanel::onCmdDirMan(FXObject* sender,FXSelector sel,void* ptr)
 	
 	// Go to target directory and refresh the DirList
 	list->setDirectory(target,TRUE);
-	((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(target);
-	((XFileExplorer*) mainWindow)->lpanel->current->updatePathLinker();
+	((XFileExplorer*) mainWindow)->getCurrentPanel()->setDirectory(target);
+	((XFileExplorer*) mainWindow)->getCurrentPanel()->updatePathLinker();
 	list->handle(this,FXSEL(SEL_COMMAND,DirList::ID_REFRESH),NULL);
     return 1;
 }
@@ -1627,8 +1620,8 @@ long DirPanel::onCmdDirDelete(FXObject*,FXSelector,void*)
 			
 			// Return to parent directory in DirList and FileList
 			list->setDirectory(parentdir,TRUE);
-			((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(parentdir);
-			((XFileExplorer*) mainWindow)->lpanel->current->updatePathLinker();
+			((XFileExplorer*) mainWindow)->getCurrentPanel()->setDirectory(parentdir);
+			((XFileExplorer*) mainWindow)->getCurrentPanel()->updatePathLinker();
 		}
 	}
 
@@ -1645,8 +1638,8 @@ long DirPanel::onCmdDirDelete(FXObject*,FXSelector,void*)
 		}
 		// Return to parent directory in DirList and FileList
 		list->setDirectory(parentdir,TRUE);
-		((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(parentdir);
-		((XFileExplorer*) mainWindow)->lpanel->current->updatePathLinker();
+		((XFileExplorer*) mainWindow)->getCurrentPanel()->setDirectory(parentdir);
+		((XFileExplorer*) mainWindow)->getCurrentPanel()->updatePathLinker();
 	}
 
 end:
@@ -1751,8 +1744,8 @@ long DirPanel::onCmdDirTrash(FXObject*,FXSelector,void*)
 			
 			// Return to parent directory in DirList and FileList
 			list->setDirectory(parentdir,TRUE);
-			((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(parentdir);
-			((XFileExplorer*) mainWindow)->lpanel->current->updatePathLinker();
+			((XFileExplorer*) mainWindow)->getCurrentPanel()->setDirectory(parentdir);
+			((XFileExplorer*) mainWindow)->getCurrentPanel()->updatePathLinker();
 		}
 	}
 
@@ -1793,8 +1786,8 @@ long DirPanel::onCmdDirTrash(FXObject*,FXSelector,void*)
 		}
 		// Return to parent directory in DirList and FileList
 		list->setDirectory(parentdir,TRUE);
-		((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(parentdir);
-		((XFileExplorer*) mainWindow)->lpanel->current->updatePathLinker();
+		((XFileExplorer*) mainWindow)->getCurrentPanel()->setDirectory(parentdir);
+		((XFileExplorer*) mainWindow)->getCurrentPanel()->updatePathLinker();
 	}
 
 end:
@@ -2144,3 +2137,5 @@ long DirPanel::onUpdTitle(FXObject* sender,FXSelector,void*)
 		mainWindow->setTitle("Xfe - " + path);
     return 1;
 }
+
+
