@@ -1115,8 +1115,8 @@ void EditWindow::loadConfig()
 	{
 		ww=getApp()->reg().readUnsignedEntry("OPTIONS","width",DEFAULT_WINDOW_WIDTH);
 		hh=getApp()->reg().readUnsignedEntry("OPTIONS","height",DEFAULT_WINDOW_HEIGHT);
-		xx=getApp()->reg().readIntEntry("OPTIONS","xpos",0);
-		yy=getApp()->reg().readIntEntry("OPTIONS","ypos",0);
+		xx=getApp()->reg().readIntEntry("OPTIONS","xpos",DEFAULT_WINDOW_XPOS);
+		yy=getApp()->reg().readIntEntry("OPTIONS","ypos",DEFAULT_WINDOW_YPOS);
 	}
 
     // Showing the status line?
