@@ -16,7 +16,8 @@
 #include "MessageBox.h"
 #include "icons.h"
 
-#define FILELISTMASK (ICONLIST_EXTENDEDSELECT|ICONLIST_SINGLESELECT|ICONLIST_BROWSESELECT|ICONLIST_MULTIPLESELECT)
+#define FILELISTMASK (_ICONLIST_EXTENDEDSELECT|_ICONLIST_SINGLESELECT|_ICONLIST_BROWSESELECT|_ICONLIST_MULTIPLESELECT)
+#define FILESTYLEMASK (_ICONLIST_DETAILED|_ICONLIST_MINI_ICONS|_ICONLIST_BIG_ICONS|_ICONLIST_ROWS|_ICONLIST_COLUMNS|_ICONLIST_AUTOSIZE)
 
 // Single click navigation
 extern FXuint single_click;
@@ -47,6 +48,7 @@ FXDEFMAP(FileSelector) FileSelectorMap[]=
 	FXMAPFUNC(SEL_UPDATE,FileSelector::ID_DIR_FORWARD_HIST,FileSelector::onUpdDirForwardHist),
 	FXMAPFUNC(SEL_COMMAND,FileSelector::ID_HOME,FileSelector::onCmdHome),
 	FXMAPFUNC(SEL_COMMAND,FileSelector::ID_NEWDIR,FileSelector::onCmdNewDir),
+	FXMAPFUNC(SEL_COMMAND,FileSelector::ID_NEWFILE,FileSelector::onCmdNewFile),
 	FXMAPFUNC(SEL_COMMAND,FileSelector::ID_WORK,FileSelector::onCmdWork),
 	FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,FileSelector::ID_FILELIST,FileSelector::onCmdPopupMenu),
 };
@@ -83,27 +85,27 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint op
  	FXuint options;
 	FXbool smoothscroll=getApp()->reg().readUnsignedEntry("SETTINGS","smooth_scroll",TRUE);	
 	if (smoothscroll)
-		options=ICONLIST_MINI_ICONS|ICONLIST_BROWSESELECT|ICONLIST_AUTOSIZE|LAYOUT_FILL_X|LAYOUT_FILL_Y;
+		options=_ICONLIST_MINI_ICONS|_ICONLIST_BROWSESELECT|LAYOUT_FILL_X|LAYOUT_FILL_Y;
 	else
-		options=ICONLIST_MINI_ICONS|ICONLIST_BROWSESELECT|ICONLIST_AUTOSIZE|LAYOUT_FILL_X|LAYOUT_FILL_Y|SCROLLERS_DONT_TRACK;
+		options=_ICONLIST_MINI_ICONS|_ICONLIST_BROWSESELECT|LAYOUT_FILL_X|LAYOUT_FILL_Y|SCROLLERS_DONT_TRACK;
     list=new FileList(this,cont,this,ID_FILELIST,options);
     
 	// Set list colors and columns size for detailed mode
 	list->setTextColor(getApp()->reg().readColorEntry("SETTINGS","listforecolor",FXRGB(0,0,0)));
 	list->setBackColor(getApp()->reg().readColorEntry("SETTINGS","listbackcolor",FXRGB(255,255,255)));
-	list->setHeaderSize(0,getApp()->reg().readUnsignedEntry("OPTIONS","filedialog_name_size",200));
-    list->setHeaderSize(1,getApp()->reg().readUnsignedEntry("OPTIONS","filedialog_size_size",60));
-    list->setHeaderSize(2,getApp()->reg().readUnsignedEntry("OPTIONS","filedialog_type_size",100));
-    list->setHeaderSize(3,getApp()->reg().readUnsignedEntry("OPTIONS","filedialog_ext_size",100));
-    list->setHeaderSize(4,getApp()->reg().readUnsignedEntry("OPTIONS","filedialog_modd_size",150));
-    list->setHeaderSize(5,getApp()->reg().readUnsignedEntry("OPTIONS","filedialog_user_size",50));
-    list->setHeaderSize(6,getApp()->reg().readUnsignedEntry("OPTIONS","filedialog_grou_size",50));
-    list->setHeaderSize(7,getApp()->reg().readUnsignedEntry("OPTIONS","filedialog_attr_size",100));  	
+	list->setHeaderSize(0,getApp()->reg().readUnsignedEntry("FILEDIALOG","name_size",200));
+    list->setHeaderSize(1,getApp()->reg().readUnsignedEntry("FILEDIALOG","size_size",60));
+    list->setHeaderSize(2,getApp()->reg().readUnsignedEntry("FILEDIALOG","type_size",100));
+    list->setHeaderSize(3,getApp()->reg().readUnsignedEntry("FILEDIALOG","ext_size",100));
+    list->setHeaderSize(4,getApp()->reg().readUnsignedEntry("FILEDIALOG","modd_size",150));
+    list->setHeaderSize(5,getApp()->reg().readUnsignedEntry("FILEDIALOG","user_size",50));
+    list->setHeaderSize(6,getApp()->reg().readUnsignedEntry("FILEDIALOG","grou_size",50));
+    list->setHeaderSize(7,getApp()->reg().readUnsignedEntry("FILEDIALOG","attr_size",100));  	
 	
 	// Set file selector options
-	FXuint listmode=getApp()->reg().readUnsignedEntry("OPTIONS","filedialog_listmode",ICONLIST_MINI_ICONS);
-	FXbool hiddenfiles=getApp()->reg().readUnsignedEntry("OPTIONS","filedialog_hiddenfiles",FALSE);
-	FXbool thumbnails=getApp()->reg().readUnsignedEntry("OPTIONS","filedialog_thumbnails",FALSE);
+	FXuint listmode=getApp()->reg().readUnsignedEntry("FILEDIALOG","listmode",_ICONLIST_MINI_ICONS);
+	FXbool hiddenfiles=getApp()->reg().readUnsignedEntry("FILEDIALOG","hiddenfiles",FALSE);
+	FXbool thumbnails=getApp()->reg().readUnsignedEntry("FILEDIALOG","thumbnails",FALSE);
 	showHiddenFiles(hiddenfiles);
 	setFileBoxStyle	(listmode);
 	showThumbnails(thumbnails);
@@ -132,8 +134,8 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint op
     new FXButton(buttons,_("\tGo to home folder\tBack to home folder."),homeicon,this,ID_HOME,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
     new FXButton(buttons,_("\tGo to working folder\tBack to working folder."),workicon,this,ID_WORK,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
     new FXButton(buttons,_("\tNew folder\tCreate new folder."),newfoldericon,this,ID_NEWDIR,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
-    new FXButton(buttons,_("\tShow list\tDisplay folder with small icons."),smalliconsicon,list,FileList::ID_SHOW_MINI_ICONS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
     new FXButton(buttons,_("\tShow icons\tDisplay folder with big icons."),bigiconsicon,list,FileList::ID_SHOW_BIG_ICONS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+    new FXButton(buttons,_("\tShow list\tDisplay folder with small icons."),smalliconsicon,list,FileList::ID_SHOW_MINI_ICONS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
     new FXButton(buttons,_("\tShow details\tDisplay detailed folder listing."),detailsicon,list,FileList::ID_SHOW_DETAILS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
     new FXToggleButton(buttons,_("\tShow hidden files\tShow hidden files and folders."),_("\tHide hidden Files\tHide hidden files and folders."),showhiddenicon,hidehiddenicon,list,FileList::ID_TOGGLE_HIDDEN,TOGGLEBUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
     new FXToggleButton(buttons,_("\tShow thumbnails"),_("\tHide thumbnails"),showthumbicon,hidethumbicon,list,FileList::ID_TOGGLE_THUMBNAILS,TOGGLEBUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
@@ -176,17 +178,17 @@ long FileSelector::onCmdItemDoubleClicked(FXObject*,FXSelector,void* ptr)
     // If directory, open the directory
     if(list->isItemDirectory(index))
     {
-		FXString filepath=list->getItemPathname(index);
+		FXString pathname=list->getItemPathname(index);
 
 		// Does not have access
-		if(!::isReadExecutable(filepath))
+		if(!::isReadExecutable(pathname))
 		{
-			MessageBox::error(this,BOX_OK,_("Error"),_(" Permission to: %s denied."), filepath.text());
+			MessageBox::error(this,BOX_OK,_("Error"),_(" Permission to: %s denied."), pathname.text());
 			return 0;
 		}
 		
-        setDirectory(filepath);
-		pathlink->setPath(filepath);
+        setDirectory(pathname);
+		pathlink->setPath(pathname);
         return 1;
     }
 
@@ -214,10 +216,13 @@ long FileSelector::onCmdItemClicked(FXObject*,FXSelector,void* ptr)
 		if(index<0)
 			return 1;
 
-		// Test if a key modifier was pressed
+		// In detailed mode, avoid single click when cursor is not over the first column
 		FXint x, y;
 		FXuint state;
 		getCursorPosition(x,y,state);
+		FXbool allow=TRUE;
+		if (!(list->getListStyle()&(_ICONLIST_BIG_ICONS|_ICONLIST_MINI_ICONS)) && (x-list->getXPosition())>list->getHeaderSize(0))
+			allow=FALSE;
 
 		// Single click with control or shift
 		if (state&(CONTROLMASK|SHIFTMASK))
@@ -227,21 +232,21 @@ long FileSelector::onCmdItemClicked(FXObject*,FXSelector,void* ptr)
 		else
 		{
 			// If directory, open the directory
-			if(single_click != SINGLE_CLICK_NONE && list->isItemDirectory(index))
+			if(single_click != SINGLE_CLICK_NONE && list->isItemDirectory(index) && allow)
 			{
-				FXString filepath=list->getItemPathname(index);
+				FXString pathname=list->getItemPathname(index);
 
 				// Does not have access
-				if(!::isReadExecutable(filepath))
+				if(!::isReadExecutable(pathname))
 				{
-					MessageBox::error(this,BOX_OK,_("Error"),_(" Permission to: %s denied."), filepath.text());
+					MessageBox::error(this,BOX_OK,_("Error"),_(" Permission to: %s denied."), pathname.text());
 					return 0;
 				}				
-				setDirectory(filepath);
-				pathlink->setPath(filepath);
+				setDirectory(pathname);
+				pathlink->setPath(pathname);
 				return 1;
 			}
-			else if((single_click==SINGLE_CLICK_DIR_FILE) && list->isItemFile(index))
+			else if((single_click==SINGLE_CLICK_DIR_FILE) && list->isItemFile(index) && allow)
 			{
 				FXObject *tgt=accept->getTarget();
 				FXSelector sel=accept->getSelector();
@@ -773,7 +778,7 @@ long FileSelector::onCmdHome(FXObject*,FXSelector,void*)
 // Create new directory
 long FileSelector::onCmdNewDir(FXObject*,FXSelector,void*)
 {
-	// Current item
+	// Focus on current list
 	list->setFocus();
 
     FXString dirname="";	
@@ -810,6 +815,66 @@ long FileSelector::onCmdNewDir(FXObject*,FXSelector,void*)
 }
 
 
+// Create new file
+long FileSelector::onCmdNewFile(FXObject*,FXSelector,void*)
+{
+	FXString filename="";
+	
+	// Focus on current list
+    list->setFocus();
+
+    FXString pathname=list->getDirectory();
+    if(pathname!=ROOTDIR)
+        pathname+=PATHSEPSTRING;
+
+    InputDialog* dialog=new InputDialog(this,filename,_("Create new file..."),_("New File"));
+    dialog->CursorEnd();
+    
+	// Accept was pressed
+    if(dialog->execute(PLACEMENT_CURSOR))
+    {	
+		filename=pathname+dialog->getText();
+		FILE *file;
+		if(filename!=pathname)
+        {
+			// Test some error conditions
+			if (::exists(filename))
+        	{
+				MessageBox::error(this,BOX_OK,_("Error"),_("File or folder %s already exists"), filename.text());
+        		return 0;
+			}
+			// Create the new file
+			if (!(file=fopen(filename.text(),"w+"))  ||  fclose(file) )
+			{
+				if (errno)
+					MessageBox::error(this,BOX_OK_SU,_("Error"),"Can't create file %s: %s",filename.text(),strerror(errno));
+				else
+					MessageBox::error(this,BOX_OK_SU,_("Error"),"Can't create file %s",filename.text());
+    			return 0;
+			}
+			// Change the file permissions according to the current umask
+			int mask;
+			mask=umask(0);
+			umask(mask);
+			if (chmod(filename.text(), 438 & ~mask) != 0)
+			{
+				if (errno)
+					MessageBox::error(this,BOX_OK_SU,_("Error"),"Can't set permissions in %s: %s",filename.text(),strerror(errno));
+				else
+					MessageBox::error(this,BOX_OK_SU,_("Error"),"Can't set permissions in %s",filename.text());
+				return 0;
+			}
+		}							
+    }
+    delete dialog;
+	
+	
+	return 1;
+}
+
+
+
+
 // Back to current working directory
 long FileSelector::onCmdWork(FXObject*,FXSelector,void*)
 {
@@ -1100,17 +1165,18 @@ FXint FileSelector::getItemSpace() const
 // Change File List style
 void FileSelector::setFileBoxStyle(FXuint style)
 {
-    list->setListStyle(style);
+	list->setListStyle((list->getListStyle()&~FILESTYLEMASK) | (style&FILESTYLEMASK));
 }
 
 
 // Return File List style
 FXuint FileSelector::getFileBoxStyle() const
 {
-    return list->getListStyle();
+    return list->getListStyle()&FILESTYLEMASK;
 }
 
 
+
 // Change file selection mode
 void FileSelector::setSelectMode(FXuint mode)
 {
@@ -1118,23 +1184,23 @@ void FileSelector::setSelectMode(FXuint mode)
     {
     case SELECT_FILE_EXISTING:
         list->showOnlyDirectories(FALSE);
-        list->setListStyle((list->getListStyle()&~FILELISTMASK)|ICONLIST_BROWSESELECT);
+        list->setListStyle((list->getListStyle()&~FILELISTMASK)|_ICONLIST_BROWSESELECT);
         break;
     case SELECT_FILE_MULTIPLE:
     case SELECT_FILE_MULTIPLE_ALL:
         list->showOnlyDirectories(FALSE);
-        list->setListStyle((list->getListStyle()&~FILELISTMASK)|ICONLIST_EXTENDEDSELECT);
+        list->setListStyle((list->getListStyle()&~FILELISTMASK)|_ICONLIST_EXTENDEDSELECT);
         break;
     case SELECT_FILE_DIRECTORY:
         list->showOnlyDirectories(TRUE);
-        list->setListStyle((list->getListStyle()&~FILELISTMASK)|ICONLIST_BROWSESELECT);
+        list->setListStyle((list->getListStyle()&~FILELISTMASK)|_ICONLIST_BROWSESELECT);
         break;
     case SELECT_FILE_MIXED:
-        list->setListStyle((list->getListStyle()&~FILELISTMASK)|ICONLIST_BROWSESELECT);
+        list->setListStyle((list->getListStyle()&~FILELISTMASK)|_ICONLIST_BROWSESELECT);
         break;
     default:
         list->showOnlyDirectories(FALSE);
-        list->setListStyle((list->getListStyle()&~FILELISTMASK)|ICONLIST_BROWSESELECT);
+        list->setListStyle((list->getListStyle()&~FILELISTMASK)|_ICONLIST_BROWSESELECT);
         break;
     }
     selectmode=mode;
@@ -1202,17 +1268,17 @@ void FileSelector::showThumbnails(FXbool shown)
 FileSelector::~FileSelector()
 {	
 	// Write options to the registry
-	getApp()->reg().writeUnsignedEntry("OPTIONS","filedialog_name_size",list->getHeaderSize(0));
-	getApp()->reg().writeUnsignedEntry("OPTIONS","filedialog_size_size",list->getHeaderSize(1));
-	getApp()->reg().writeUnsignedEntry("OPTIONS","filedialog_type_size",list->getHeaderSize(2));
-	getApp()->reg().writeUnsignedEntry("OPTIONS","filedialog_ext_size",list->getHeaderSize(3));
-	getApp()->reg().writeUnsignedEntry("OPTIONS","filedialog_modd_size",list->getHeaderSize(4));
-	getApp()->reg().writeUnsignedEntry("OPTIONS","filedialog_user_size",list->getHeaderSize(5));
-	getApp()->reg().writeUnsignedEntry("OPTIONS","filedialog_grou_size",list->getHeaderSize(6));
-	getApp()->reg().writeUnsignedEntry("OPTIONS","filedialog_attr_size",list->getHeaderSize(7));
-	getApp()->reg().writeUnsignedEntry("OPTIONS","filedialog_listmode",getFileBoxStyle());
-	getApp()->reg().writeUnsignedEntry("OPTIONS","filedialog_hiddenfiles",shownHiddenFiles());
-	getApp()->reg().writeUnsignedEntry("OPTIONS","filedialog_thumbnails",shownThumbnails());
+	getApp()->reg().writeUnsignedEntry("FILEDIALOG","name_size",list->getHeaderSize(0));
+	getApp()->reg().writeUnsignedEntry("FILEDIALOG","size_size",list->getHeaderSize(1));
+	getApp()->reg().writeUnsignedEntry("FILEDIALOG","type_size",list->getHeaderSize(2));
+	getApp()->reg().writeUnsignedEntry("FILEDIALOG","ext_size",list->getHeaderSize(3));
+	getApp()->reg().writeUnsignedEntry("FILEDIALOG","modd_size",list->getHeaderSize(4));
+	getApp()->reg().writeUnsignedEntry("FILEDIALOG","user_size",list->getHeaderSize(5));
+	getApp()->reg().writeUnsignedEntry("FILEDIALOG","grou_size",list->getHeaderSize(6));
+	getApp()->reg().writeUnsignedEntry("FILEDIALOG","attr_size",list->getHeaderSize(7));
+	getApp()->reg().writeUnsignedEntry("FILEDIALOG","listmode",getFileBoxStyle());
+	getApp()->reg().writeUnsignedEntry("FILEDIALOG","hiddenfiles",shownHiddenFiles());
+	getApp()->reg().writeUnsignedEntry("FILEDIALOG","thumbnails",shownThumbnails());
 	getApp()->reg().write();
 	
 	FXAccelTable *table=getShell()->getAccelTable();
@@ -1247,6 +1313,7 @@ long FileSelector::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
 
 	new FXMenuCommand(&menu,_("Go ho&me"),homeicon,this,ID_HOME);
 	new FXMenuCommand(&menu,_("Go &work"),workicon,this,ID_WORK);
+	new FXMenuCommand(&menu,_("New &file..."),newfileicon,this,ID_NEWFILE);
 	new FXMenuCommand(&menu,_("New f&older..."),newfoldericon,this,ID_NEWDIR);
 	new FXMenuSeparator(&menu);
 	new FXMenuCheck(&menu,_("&Hidden files"),list,FileList::ID_TOGGLE_HIDDEN);
@@ -1254,18 +1321,22 @@ long FileSelector::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
 	new FXMenuSeparator(&menu);
 	new FXMenuRadio(&menu,_("B&ig icons"),list,IconList::ID_SHOW_BIG_ICONS);
 	new FXMenuRadio(&menu,_("&Small icons"),list,IconList::ID_SHOW_MINI_ICONS);
-	new FXMenuRadio(&menu,_("F&ull file list"),list,IconList::ID_SHOW_DETAILS);
+	new FXMenuRadio(&menu,_("Fu&ll file list"),list,IconList::ID_SHOW_DETAILS);
 	new FXMenuSeparator(&menu);
 	new FXMenuRadio(&menu,_("&Rows"),list,FileList::ID_ARRANGE_BY_ROWS);
 	new FXMenuRadio(&menu,_("&Columns"),list,FileList::ID_ARRANGE_BY_COLUMNS);
+	new FXMenuCheck(&menu,_("Autosize"),list,FileList::ID_AUTOSIZE);
 	new FXMenuSeparator(&menu);
 	new FXMenuRadio(&menu,_("&Name"),list,FileList::ID_SORT_BY_NAME);
 	new FXMenuRadio(&menu,_("Si&ze"),list,FileList::ID_SORT_BY_SIZE);
 	new FXMenuRadio(&menu,_("&Type"),list,FileList::ID_SORT_BY_TYPE);
 	new FXMenuRadio(&menu,_("E&xtension"),list,FileList::ID_SORT_BY_EXT);
 	new FXMenuRadio(&menu,_("&Date"),list,FileList::ID_SORT_BY_TIME);
+	new FXMenuRadio(&menu,_("&User"),list,FileList::ID_SORT_BY_USER);
+	new FXMenuRadio(&menu,_("&Group"),list,FileList::ID_SORT_BY_GROUP);
+	new FXMenuRadio(&menu,_("&Permissions"),list,FileList::ID_SORT_BY_PERM);
 	new FXMenuSeparator(&menu);
-	new FXMenuCheck(&menu,_("I&gnore case"),list,FileList::ID_SORT_CASE);
+	new FXMenuCheck(&menu,_("Ignore c&ase"),list,FileList::ID_SORT_CASE);
 	new FXMenuCheck(&menu,_("Dir&ectories first"),list,FileList::ID_DIRS_FIRST);
 	new FXMenuCheck(&menu,_("Re&verse order"),list,FileList::ID_SORT_REVERSE);
 
@@ -1294,8 +1365,8 @@ FileDialog::FileDialog(FXWindow* owner,const FXString& name,FXuint opts,FXint x,
     list->cancelButton()->setSelector(DialogBox::ID_CANCEL);
     
     // Set file dialog options 
-	FXuint width=getApp()->reg().readUnsignedEntry("OPTIONS","filedialog_width",640);
-	FXuint height=getApp()->reg().readUnsignedEntry("OPTIONS","filedialog_height",480);
+	FXuint width=getApp()->reg().readUnsignedEntry("FILEDIALOG","width",640);
+	FXuint height=getApp()->reg().readUnsignedEntry("FILEDIALOG","height",480);
 	setWidth(width);
 	setHeight(height);
 }
@@ -1499,8 +1570,8 @@ void FileDialog::showThumbnails(FXbool shown)
 FileDialog::~FileDialog()
 {
 	// Write options to the registry
-	getApp()->reg().writeUnsignedEntry("OPTIONS","filedialog_width",getWidth());
-	getApp()->reg().writeUnsignedEntry("OPTIONS","filedialog_height",getHeight());
+	getApp()->reg().writeUnsignedEntry("FILEDIALOG","width",getWidth());
+	getApp()->reg().writeUnsignedEntry("FILEDIALOG","height",getHeight());
 	getApp()->reg().write();
 
     delete list;
