@@ -744,6 +744,8 @@ void PropertiesBox::create()
 }
 
 
+
+// Dialog for multiple selected files
 long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
 {
     int rc=0,i;
@@ -869,16 +871,13 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
     }
 
 	// Redraw the file lists
-	((XFileExplorer*) mainWindow)->rpanel->list->recalc();
-	((XFileExplorer*) mainWindow)->lpanel->list->recalc();
-
-	// FilePanel and DirPanel refresh
-	//mainWindow->handle(this,FXSEL(SEL_COMMAND,XFileExplorer::ID_REFRESH),NULL);
+	((XFileExplorer*) mainWindow)->redrawPanels();
 
     return 1;
 }
 
 
+// Dialog for single selected file
 long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 {
 	char **str=NULL;
@@ -925,8 +924,19 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 			mainWindow->handle(this,FXSEL(SEL_COMMAND,XFileExplorer::ID_FILE_ASSOC),str);
     	}
 	}
-    // Rename file
+    
+    // Source and target path names
+	FXString targetpath;
+	FXString sourcepath=parentdir+"/"+source;  
     FXString target=input->getText();
+	FXString targetparentdir=FXPath::directory(target);
+	if (targetparentdir=="")
+	{
+		targetparentdir=parentdir;
+		targetpath=targetparentdir+"/"+target;
+	}
+	else
+		targetpath=target;
 	
 	// Nothing entered
 	if (target=="")
@@ -936,16 +946,14 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 		return 0;
 	}
 
+    // Rename file if necessary
 	if(source != target)
 	{
-		// Source is not writable
-		if (!::isWritable(source))
+		// Source path is not writable	
+		if (!::isWritable(sourcepath))
         	MessageBox::error(this,BOX_OK_SU,_("Error"),_("Can't write to %s: Permission denied"),source.text());
 		
 		// Target parent directory doesn't exist or is not writable
-		FXString targetparentdir=FXPath::directory(target);
-		if (targetparentdir=="")
-			targetparentdir=parentdir;
 		if (!::exists(targetparentdir))
         {
 			MessageBox::error(this,BOX_OK,_("Error"),_("Folder %s doesn't exist"),targetparentdir.text());
@@ -963,14 +971,14 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 			File *f;
 			f=new File(this,_("File rename"),RENAME);
        		f->create();
-			f->rename(source,input->getText());
+			f->rename(sourcepath,targetpath);
 			delete f;
 		}
 	}
 
     // Change perm
     DialogBox::onCmdAccept(o,s,p);
-	if (input->getText()==".." || input->getText()==".")
+	if (target==".." || target==".")
 	{
 		input->setText(source);
 		return 1;
@@ -981,8 +989,7 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
         struct stat info;
         mode_t m;
 		
-		FXString filepath=parentdir+"/"+input->getText().text();
-        if(lstatrep(filepath.text(),&info)!=0)
+        if(lstatrep(targetpath.text(),&info)!=0)
             return 1;
 			
         f = new File(this,_("File permissions"),CHMOD);
@@ -1007,7 +1014,7 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 		getApp()->beginWaitCursor();
 		
 		// Perform chmod on the selected file or directory
-		rc=f->chmod(strdup(filepath.text()),file,m,perm->rec->getCheck(),perm->dironly->getCheck(),perm->fileonly->getCheck());
+		rc=f->chmod(strdup(targetpath.text()),file,m,perm->rec->getCheck(),perm->dironly->getCheck(),perm->fileonly->getCheck());
 
 		// If action is cancelled in progress dialog
 		if (f->isCancelled)
@@ -1056,8 +1063,7 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 		getApp()->beginWaitCursor();
 
         // Perform chown on the selected file or directory
-		FXString filepath=parentdir+"/"+input->getText().text();
-		rc = f->chown(strdup(filepath.text()),file,uid,gid,perm->rec->getCheck(),perm->dironly->getCheck(),perm->fileonly->getCheck());
+		rc = f->chown(strdup(targetpath.text()),file,uid,gid,perm->rec->getCheck(),perm->dironly->getCheck(),perm->fileonly->getCheck());
 
 		// If action is cancelled in progress dialog
 		if (f->isCancelled)
@@ -1082,11 +1088,7 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
     }
 	
 	// Redraw the file lists
-	((XFileExplorer*) mainWindow)->rpanel->list->recalc();
-	((XFileExplorer*) mainWindow)->lpanel->list->recalc();
-
-	// FilePanel and DirPanel refresh
-	//mainWindow->handle(this,FXSEL(SEL_COMMAND,XFileExplorer::ID_REFRESH),NULL);
+	((XFileExplorer*) mainWindow)->redrawPanels();
 
     return 1;
 }
@@ -1096,8 +1098,7 @@ long PropertiesBox::onCmdCancel(FXObject* o,FXSelector s,void* p)
     DialogBox::onCmdCancel(o,s,p);
 	
 	// Redraw the file lists
-	((XFileExplorer*) mainWindow)->rpanel->list->recalc();
-	((XFileExplorer*) mainWindow)->lpanel->list->recalc();
+	((XFileExplorer*) mainWindow)->redrawPanels();
 
 	return 1;
 }
