@@ -286,8 +286,8 @@ void ViewWindow::create()
 	{
 		ww=getApp()->reg().readUnsignedEntry("OPTIONS","width",DEFAULT_WINDOW_WIDTH);
 		hh=getApp()->reg().readUnsignedEntry("OPTIONS","height",DEFAULT_WINDOW_HEIGHT);
-		xx=getApp()->reg().readIntEntry("OPTIONS","xpos",0);
-		yy=getApp()->reg().readIntEntry("OPTIONS","ypos",0);
+		xx=getApp()->reg().readIntEntry("OPTIONS","xpos",DEFAULT_WINDOW_XPOS);
+		yy=getApp()->reg().readIntEntry("OPTIONS","ypos",DEFAULT_WINDOW_YPOS);
 	}
 
 	// Get toolbar status
