@@ -129,8 +129,6 @@ FXDEFMAP(XFileImage) XFileImageMap[]=
 	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_SHOW_DETAILS,XFileImage::onCmdShowDetails),
 	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_SHOW_MINI,XFileImage::onCmdShowMini),
 	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_SHOW_BIG,XFileImage::onCmdShowBig),
-	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ROWS,XFileImage::onCmdShowRows),
-	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_COLS,XFileImage::onCmdShowCols),
 	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ROTATE_90,XFileImage::onCmdRotate),
 	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_ROTATE_270,XFileImage::onCmdRotate),
 	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_MIRROR_HOR,XFileImage::onCmdMirror),
@@ -163,8 +161,6 @@ FXDEFMAP(XFileImage) XFileImageMap[]=
 	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_SHOW_BIG,XFileImage::onUpdFileView),
 	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_SHOW_MINI,XFileImage::onUpdFileView),
 	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_SHOW_DETAILS,XFileImage::onUpdFileView),                                        
-	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_ROWS,XFileImage::onUpdIconView),
-	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_COLS,XFileImage::onUpdIconView),
 	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_TOGGLE_HIDDEN,XFileImage::onUpdToggleHidden),
 	FXMAPFUNC(SEL_UPDATE,XFileImage::ID_TOGGLE_THUMBNAILS,XFileImage::onUpdToggleThumbnails),
 	FXMAPFUNC(SEL_COMMAND,XFileImage::ID_TOGGLE_FIT_WIN,XFileImage::onCmdToggleFitWin),
@@ -244,9 +240,9 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL)
 	// File list
 	FXuint options;
 	if (smoothscroll)
-		options=LAYOUT_FILL_X|LAYOUT_FILL_Y|ICONLIST_MINI_ICONS|ICONLIST_AUTOSIZE|ICONLIST_BROWSESELECT;
+		options=LAYOUT_FILL_X|LAYOUT_FILL_Y|_ICONLIST_MINI_ICONS|_ICONLIST_BROWSESELECT;
 	else
-		options=LAYOUT_FILL_X|LAYOUT_FILL_Y|ICONLIST_MINI_ICONS|ICONLIST_AUTOSIZE|ICONLIST_BROWSESELECT|SCROLLERS_DONT_TRACK;
+		options=LAYOUT_FILL_X|LAYOUT_FILL_Y|_ICONLIST_MINI_ICONS|_ICONLIST_BROWSESELECT|SCROLLERS_DONT_TRACK;
     filelist=new FileList(this,fileframe,this,ID_FILELIST,options);
 	filelist->setTextColor(listforecolor);
 	filelist->setBackColor(listbackcolor);
@@ -268,8 +264,8 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL)
     new FXButton(buttons,_("\tGo up one folder\tMove up to higher folder."),dirupicon,this,ID_DIR_UP,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
     new FXButton(buttons,_("\tGo to home folder\tBack to home folder."),homeicon,this,ID_HOME,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
     new FXButton(buttons,_("\tGo to working folder\tBack to working folder."),workicon,this,ID_WORK,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
-    new FXButton(buttons,_("\tShow list\tDisplay folder with small icons."),smalliconsicon,this,ID_SHOW_MINI,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
     new FXButton(buttons,_("\tShow icons\tDisplay folder with big icons."),bigiconsicon,this,ID_SHOW_BIG,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
+    new FXButton(buttons,_("\tShow list\tDisplay folder with small icons."),smalliconsicon,this,ID_SHOW_MINI,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
     new FXButton(buttons,_("\tShow details\tDisplay detailed folder listing."),detailsicon,this,ID_SHOW_DETAILS,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
 
     // Path linker
@@ -453,8 +449,9 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL)
     new FXMenuRadio(viewmenu,_("&Small icons\tF11\tDisplay folders with small icons (F11)."),this,ID_SHOW_MINI);
     new FXMenuRadio(viewmenu,_("&Full file list\tF12\tDisplay detailed folder listing (F12)."),this,ID_SHOW_DETAILS);
     new FXMenuSeparator(viewmenu);
-    new FXMenuRadio(viewmenu,_("&Rows of icons\t\tView row-wise."),this,ID_ROWS);
-    new FXMenuRadio(viewmenu,_("&Columns of icons\t\tView column-wise."),this,ID_COLS);
+    new FXMenuRadio(viewmenu,_("&Rows\t\tView icons row-wise."),filelist,FileList::ID_ARRANGE_BY_ROWS);
+    new FXMenuRadio(viewmenu,_("&Columns\t\tView icons column-wise."),filelist,FileList::ID_ARRANGE_BY_COLUMNS);
+    new FXMenuCheck(viewmenu,_("&Autosize\t\tAutosize icon names."),filelist,FileList::ID_AUTOSIZE);
 
     // Help Menu entries
     new FXMenuCommand(helpmenu,_("&About X File Image\tF1\tAbout X File Image (F1)."),NULL,this,ID_ABOUT,0);
@@ -474,7 +471,6 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL)
 	
 	// Initialize some flags
 	fileview=ID_SHOW_MINI;
-	iconview=ID_COLS;
 	hiddenfiles=FALSE;	
 	thumbnails=FALSE;	
 	
@@ -523,18 +519,22 @@ long XFileImage::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
 	new FXMenuSeparator(&menu);
 	new FXMenuRadio(&menu,_("B&ig icons"),this,ID_SHOW_BIG);
 	new FXMenuRadio(&menu,_("&Small icons"),this,ID_SHOW_MINI);
-	new FXMenuRadio(&menu,_("F&ull file list"),this,ID_SHOW_DETAILS);
+	new FXMenuRadio(&menu,_("Fu&ll file list"),this,ID_SHOW_DETAILS);
 	new FXMenuSeparator(&menu);
-	new FXMenuRadio(&menu,_("&Rows"),this,ID_ROWS);
-	new FXMenuRadio(&menu,_("&Columns"),this,ID_COLS);
+	new FXMenuRadio(&menu,_("&Rows"),filelist,FileList::ID_ARRANGE_BY_ROWS);
+	new FXMenuRadio(&menu,_("&Columns"),filelist,FileList::ID_ARRANGE_BY_COLUMNS);
+	new FXMenuCheck(&menu,_("Autosize"),filelist,FileList::ID_AUTOSIZE);
 	new FXMenuSeparator(&menu);
 	new FXMenuRadio(&menu,_("&Name"),filelist,FileList::ID_SORT_BY_NAME);
 	new FXMenuRadio(&menu,_("Si&ze"),filelist,FileList::ID_SORT_BY_SIZE);
 	new FXMenuRadio(&menu,_("&Type"),filelist,FileList::ID_SORT_BY_TYPE);
 	new FXMenuRadio(&menu,_("E&xtension"),filelist,FileList::ID_SORT_BY_EXT);
 	new FXMenuRadio(&menu,_("&Date"),filelist,FileList::ID_SORT_BY_TIME);
+	new FXMenuRadio(&menu,_("&User"),filelist,FileList::ID_SORT_BY_USER);
+	new FXMenuRadio(&menu,_("&Group"),filelist,FileList::ID_SORT_BY_GROUP);
+	new FXMenuRadio(&menu,_("&Permissions"),filelist,FileList::ID_SORT_BY_PERM);
 	new FXMenuSeparator(&menu);
-	new FXMenuCheck(&menu,_("I&gnore case"),filelist,FileList::ID_SORT_CASE);
+	new FXMenuCheck(&menu,_("Ignore c&ase"),filelist,FileList::ID_SORT_CASE);
 	new FXMenuCheck(&menu,_("Dir&ectories first"),filelist,FileList::ID_DIRS_FIRST);
 	new FXMenuCheck(&menu,_("Re&verse order"),filelist,FileList::ID_SORT_REVERSE);
 
@@ -1155,21 +1155,7 @@ long XFileImage::onCmdShowDetails(FXObject*,FXSelector,void*)
     return 1;
 }
 
-// Show icons organized as rows
-long XFileImage::onCmdShowRows(FXObject*,FXSelector,void*)
-{
-	iconview=ID_ROWS;
-	filelist->handle(this,FXSEL(SEL_COMMAND,FileList::ID_ARRANGE_BY_ROWS),NULL);
-    return 1;
-}
 
-// Show icons organized as columns
-long XFileImage::onCmdShowCols(FXObject*,FXSelector,void*)
-{
-	iconview=ID_COLS;
-	filelist->handle(this,FXSEL(SEL_COMMAND,FileList::ID_ARRANGE_BY_COLUMNS),NULL);
-    return 1;
-}
 
 // Update filelist
 long XFileImage::onUpdFileView(FXObject* sender,FXSelector sel,void* ptr)
@@ -1238,35 +1224,6 @@ long XFileImage::onUpdFileView(FXObject* sender,FXSelector sel,void* ptr)
     return 1;
 }
 
-// Update icons view
-long XFileImage::onUpdIconView(FXObject* sender,FXSelector sel,void* ptr)
-{
-    // Update radio buttons
-	FXuint msg = FXWindow::ID_UNCHECK;
-		
-    switch(FXSELID(sel))
-    {
-    case ID_ROWS:
-		if (iconview==ID_ROWS)
-            msg = FXWindow::ID_CHECK;		
-        break;
-    
-	case ID_COLS:
-		if (iconview==ID_COLS)
-		    msg = FXWindow::ID_CHECK;
-        break;
-    }
-    sender->handle(this,FXSEL(SEL_COMMAND,msg),NULL);
-
-    // Disable menus items if the file list is not shown
-	if(filebox->shown())
-        sender->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
-    else
-        sender->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_DISABLE),NULL);
-
-    return 1;
-}
-
 
 // Quit
 long XFileImage::onCmdQuit(FXObject*,FXSelector,void*)
@@ -1337,10 +1294,18 @@ long XFileImage::onCmdItemClicked(FXObject* sender,FXSelector sel, void* ptr)
 {
 	if (single_click != SINGLE_CLICK_NONE)
 	{		
+		// In detailed mode, avoid single click when cursor is not over the first column
+		FXint x, y;
+		FXuint state;
+		getCursorPosition(x,y,state);
+		FXbool allow=TRUE;
+		if (!(filelist->getListStyle()&(_ICONLIST_BIG_ICONS|_ICONLIST_MINI_ICONS)) && (x-filelist->getXPosition())>filelist->getHeaderSize(0))
+			allow=FALSE;
+
 		FXint index=(FXint)(FXival)ptr;
 		if(0<=index)
 		{
-			if((single_click != SINGLE_CLICK_NONE) && filelist->isItemDirectory(index))
+			if((single_click != SINGLE_CLICK_NONE) && filelist->isItemDirectory(index) && allow)
 			{
 				FXString filepath=filelist->getItemPathname(index);
 
@@ -1353,7 +1318,7 @@ long XFileImage::onCmdItemClicked(FXObject* sender,FXSelector sel, void* ptr)
 				filelist->setDirectory(filepath);
 				pathlink->setPath(filepath);
 			}
-			else if((single_click == SINGLE_CLICK_DIR_FILE) && filelist->isItemFile(index))
+			else if((single_click == SINGLE_CLICK_DIR_FILE) && filelist->isItemFile(index) && allow)
 			{
 				filename=filelist->getItemPathname(index);
 				mrufiles.appendFile(filename);
@@ -1599,8 +1564,8 @@ void XFileImage::create()
 	// Get size and position
     FXuint ww=getApp()->reg().readUnsignedEntry("OPTIONS","width",DEFAULT_WINDOW_WIDTH);    // Workaround for a possible bug in some WMs
     FXuint hh=getApp()->reg().readUnsignedEntry("OPTIONS","height",DEFAULT_WINDOW_HEIGHT);  // Workaround for a possible bug in some WMs
-    FXint xx=getApp()->reg().readIntEntry("OPTIONS","xpos",0);
-    FXint yy=getApp()->reg().readIntEntry("OPTIONS","ypos",0);
+    FXint xx=getApp()->reg().readIntEntry("OPTIONS","xpos",DEFAULT_WINDOW_XPOS);
+    FXint yy=getApp()->reg().readIntEntry("OPTIONS","ypos",DEFAULT_WINDOW_YPOS);
     fileheight_pct=getApp()->reg().readRealEntry("OPTIONS","fileheight_pct",0.25);
     FXuint fs=getApp()->reg().readIntEntry("OPTIONS","filesshown",TRUE);
 
@@ -1633,11 +1598,13 @@ void XFileImage::create()
 	thumbnails=getApp()->reg().readUnsignedEntry("OPTIONS","thumbnails",0);
 	filelist->showThumbnails(thumbnails);
   
-	// Get file view and icon view
+	// Get list style
+	liststyle=getApp()->reg().readUnsignedEntry("OPTIONS","liststyle",(FXuint)IconList::ID_SHOW_DETAILS);
+	filelist->setListStyle(liststyle);
+
+	// Get file view
     fileview=getApp()->reg().readUnsignedEntry("OPTIONS","fileview",ID_SHOW_MINI);    
 	this->handle(this,FXSEL(SEL_COMMAND,fileview),NULL);
-    iconview=getApp()->reg().readUnsignedEntry("OPTIONS","iconview",ID_COLS);
-	this->handle(this,FXSEL(SEL_COMMAND,iconview),NULL);
 
 	// Get startup zoom
 	fitwin=getApp()->reg().readUnsignedEntry("OPTIONS","fitwin",0);
@@ -1681,9 +1648,11 @@ void XFileImage::saveConfig()
 	// Thumbnails status
 	getApp()->reg().writeUnsignedEntry("OPTIONS","thumbnails",thumbnails);
 
-	// File view and icon view
+	// File view
 	getApp()->reg().writeUnsignedEntry("OPTIONS","fileview",fileview);
-	getApp()->reg().writeUnsignedEntry("OPTIONS","iconview",iconview);
+
+	// List style
+	getApp()->reg().writeUnsignedEntry("OPTIONS","liststyle",filelist->getListStyle());
 
 	// Startup zoom
 	getApp()->reg().writeUnsignedEntry("OPTIONS","fitwin",fitwin);
@@ -1857,6 +1826,10 @@ int main(int argc,char *argv[])
 	FXRegistry* reg_xfe=new FXRegistry(xfename,vdrname);
 	reg_xfe->read();
 
+	// Set base color (to change the default base color at first run)
+	FXColor basecolor=reg_xfe->readColorEntry("SETTINGS","basecolor",FXRGB(237,233,227));
+	application->setBaseColor(basecolor);
+
 	// Set Xfi normal font according to the Xfe registry
 	FXString fontspec;
 	fontspec=reg_xfe->readStringEntry("SETTINGS","font","Helvetica,100,normal,regular");
