@@ -524,8 +524,8 @@ void XFilePackage::create()
     // Get size
     FXuint width=getApp()->reg().readUnsignedEntry("OPTIONS","width",DEFAULT_WINDOW_WIDTH);
     FXuint height=getApp()->reg().readUnsignedEntry("OPTIONS","height",DEFAULT_WINDOW_HEIGHT);
-    FXint xpos=getApp()->reg().readIntEntry("OPTIONS","xpos",0);
-    FXint ypos=getApp()->reg().readIntEntry("OPTIONS","ypos",0);
+    FXint xpos=getApp()->reg().readIntEntry("OPTIONS","xpos",DEFAULT_WINDOW_XPOS);
+    FXint ypos=getApp()->reg().readIntEntry("OPTIONS","ypos",DEFAULT_WINDOW_YPOS);
 
 	// Get toolbar status
     if(getApp()->reg().readUnsignedEntry("OPTIONS","showtoolbar",TRUE)==FALSE)
@@ -619,6 +619,10 @@ int main(int argc,char* argv[])
   	reg_xfe=new FXRegistry(xfename,vdrname);
 	reg_xfe->read();
 
+	// Set base color (to change the default base color at first run)
+	FXColor basecolor=reg_xfe->readColorEntry("SETTINGS","basecolor",FXRGB(237,233,227));
+	application->setBaseColor(basecolor);
+
 	// Set Xfp normal font according to the Xfe registry
 	FXString fontspec;
 	fontspec=reg_xfe->readStringEntry("SETTINGS","font","Helvetica,100,normal,regular");
