@@ -175,6 +175,10 @@ int main(int argc,char *argv[])
 	FXRegistry* reg_xfe=new FXRegistry(xfename,vdrname);
 	reg_xfe->read();
 
+	// Set base color (to change the default base color at first run)
+	FXColor basecolor=reg_xfe->readColorEntry("SETTINGS","basecolor",FXRGB(237,233,227));
+	application->setBaseColor(basecolor);
+
 	// Set Xfv normal font according to the Xfe registry
 	FXString fontspec;
 	fontspec=reg_xfe->readStringEntry("SETTINGS","font","Helvetica,100,normal,regular");
