@@ -10,8 +10,7 @@ class ViewWindow;
 class XFileView : public FXApp
 {
     FXDECLARE(XFileView)
-    friend class ViewWindow;
-protected:
+public:
     ViewWindowList windowlist; // Window list
 private:
     XFileView()
